All Classes and Interfaces

Class
Description
An access control policy action identifies a specific action in a service that can be performed on a resource.
AWS access control policy condition that allows an access control statement to be conditionally applied based on the comparison of an Amazon Resource Name (ARN).
Enumeration of the supported ways an ARN comparison can be evaluated.
Base class for assertion logic, used by RetryableAssertion.
 
 
AWS access control policy conditions are contained in Statement objects, and affect when a statement is applied.
Factory for creating common AWS access control policy conditions.
AWS access control policy condition that allows an access control statement to be conditionally applied based on the comparison of the current time at which a request is received, and a specific date.
Enumeration of the supported ways a date comparison can be evaluated.
 
A utility that can temporarily forcibly set environment variables and then allows resetting them to the original values.
 
 
AWS access control policy condition that allows an access control statement to be conditionally applied based on the comparison of the the incoming source IP address at the time of a request against a CIDR IP range.
Enumeration of the supported ways an IP address comparison can be evaluated.
 
 
Generate an AWS policy object by parsing the given JSON string.
Serializes an AWS policy object to a JSON string, suitable for sending to an AWS service.
A test utility that allows inspection of log statements during testing.
 
 
 
Used to retrieve information about the JVM memory.
Normally all exceptions are retried by RetryableAction.
An AWS access control policy is a object that acts as a container for one or more statements, which specify fine grained rules for allowing or denying various types of actions from being performed on your AWS resources.
A principal is an AWS account or AWS web service, which is being allowed or denied access to a resource through an access control policy.
The services who have the right to do the assume the role action.
Web identity providers, such as Login with Amazon, Facebook, or Google.
Test utility InputStream implementation that generates random ASCII data when read, up to the size specified when constructed.
Extension of File that creates a temporary file with a specified name in Java's temporary directory, as declared in the JRE's system properties.
Utility methods for doing reflection.
Represents a resource involved in an AWS access control policy statement.
Utility to repeatedly invoke an action that returns a result until it succeeds or the max allowed attempts is reached.
Utility to repeatedly invoke assertion logic until it succeeds or the max allowed attempts is reached.
Normally Error's are not retried by RetryableAction.
Parameters for RetryableAssertion.
Denotes that a method is a test template for a retryable test.
 
 
 
 
A statement is the formal description of a single permission, and is always contained within a policy object.
The effect is the result that you want a policy statement to return at evaluation time.
String conditions let you constrain AWS access control policy statements using string matching rules.
Enumeration of the supported ways a string comparison can be evaluated.
This class includes some utility methods for comparing two unordered collections.
A simple interface that attempts to compare objects of two different types
Subclass of RandomInputStream that, in addition to spitting out a set length of random characters, throws an IOException.
This retries a particular function multiple times until it returns an expected result (or fails with an exception).